@@ -5,20 +5,21 @@
 
 Helper functions.
 """
+from __future__ import annotations
 
 import ctypes
 import sys
 import time
 from datetime import datetime as dt
-from typing import Optional, Union
+from typing import Optional, Union  # typeguard doesn't support PEP604 on 3.9.x
 
 try:
     from typeguard import typechecked  # type: ignore[reportMissingImports]
-except ModuleNotFoundError:
+
+except ImportError:
 
     def typechecked(fnc):  # type: ignore[no-redef]
         def wrapper(*args, **kwargs):
-
             return fnc(*args, **kwargs)
 
         return wrapper
@@ -121,7 +122,7 @@ def dtm_from_hex(value: str) -> Optional[str]:  # from parsers
 
 
 @typechecked
-def dtm_to_hex(dtm: Union[str, dt, None], is_dst=False, incl_seconds=False) -> str:
+def dtm_to_hex(dtm: Union[None, dt, str], is_dst=False, incl_seconds=False) -> str:
     """Convert a datetime (isoformat str, or naive dtm) to a 12/14-char hex str."""
 
     def _dtm_to_hex(tm_year, tm_mon, tm_mday, tm_hour, tm_min, tm_sec, *args):
@@ -159,7 +160,7 @@ def dts_from_hex(value: str) -> Optional[str]:
 
 
 @typechecked
-def dts_to_hex(dtm: Union[str, dt, None]) -> str:  # TODO: WIP
+def dts_to_hex(dtm: Union[None, dt, str]) -> str:  # TODO: WIP
     """Convert a datetime (isoformat str, or dtm) to a packed 12-char hex str."""
     """YY-MM-DD HH:MM:SS."""
     if dtm is None:
@@ -239,7 +240,7 @@ def str_to_hex(value: str) -> str:
 
 
 @typechecked
-def temp_from_hex(value: str) -> Union[float, bool, None]:
+def temp_from_hex(value: str) -> Union[None, bool, float]:
     """Convert a 2's complement 4-byte hex string to an float."""
     if not isinstance(value, str) or len(value) != 4:
         raise ValueError(f"Invalid value: {value}, is not a 4-char hex string")
@@ -254,7 +255,7 @@ def temp_from_hex(value: str) -> Union[float, bool, None]:
 
 
 @typechecked
-def temp_to_hex(value: Union[float, None]) -> str:
+def temp_to_hex(value: Optional[float]) -> str:
     """Convert a float to a 2's complement 4-byte hex string."""
     if value is None:
         return "7FFF"  # or: "31FF"?
@@ -269,7 +270,7 @@ def temp_to_hex(value: Union[float, None]) -> str:
 
 
 @typechecked
-def valve_demand(value: str) -> dict:  # c.f. percent()
+def valve_demand(value: str) -> Optional[dict]:  # c.f. percent()
     """Convert a 2-char hex string into a percentage.
 
     The range is 0-100%, with resolution of 0.5% (high_res) or 1%.
